@@ -8,18 +8,23 @@ import traceback
 from typing import Any, Callable, Dict, Iterable, List, Set, Tuple
 import coverage
 
-from deep_serialization.deep_serialization import serialize_objects
-from deep_serialization.json_converter import DumpLoader, deserialize_memory_objects
-from deep_serialization.utils import PythonId
+from utbot_executor.deep_serialization.deep_serialization import serialize_objects
+from utbot_executor.deep_serialization.json_converter import DumpLoader, deserialize_memory_objects
+from utbot_executor.deep_serialization.utils import PythonId
 
 from utbot_executor.parser import ExecutionRequest, ExecutionResponse, ExecutionFailResponse, ExecutionSuccessResponse
 from utbot_executor.utils import suppress_stdout
 
 logging.basicConfig(
+        filename='/home/vyacheslav/executor.log',
         format='%(asctime)s | %(levelname)s | %(funcName)s - %(message)s',
         datefmt='%m/%d/%Y %H:%M:%S',
-        level=logging.INFO
+        filemode='a',
+        level=logging.DEBUG
         )
+console = logging.StreamHandler()
+console.setLevel(logging.INFO)
+logging.getLogger().addHandler(console)
 
 
 class PythonExecutor:
@@ -75,6 +80,7 @@ class PythonExecutor:
         except Exception as ex:
             logging.debug("Error \n%s", traceback.format_exc())
             return ExecutionFailResponse("fail", traceback.format_exc())
+        logging.debug("Arguments execution OK")
         value = run_calculate_function_value(
                 request.coverage_db,
                 function,
@@ -82,8 +88,11 @@ class PythonExecutor:
                 kwargs,
                 request.filepath
                 )
-        self.clear_imports()
-        self.clear_syspaths()
+        logging.debug("Function execution OK")
+        logging.debug(value)
+        # self.clear_imports()
+        # self.clear_syspaths()
+        # logging.debug("Clearing OK")
         return value
 
 
